# Memorable Password

[![Build Status](https://travis-ci.org/patarapolw/memorable-password.svg?branch=master)](https://travis-ci.org/patarapolw/memorable-password)
[![PyPI version shields.io](https://img.shields.io/pypi/v/memorable_password.svg)](https://pypi.python.org/pypi/memorable_password/)
[![PyPI license](https://img.shields.io/pypi/l/memorable_password.svg)](https://pypi.python.org/pypi/memorable_password/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/memorable_password.svg)](https://pypi.python.org/pypi/memorable_password/)
[![PyPI status](https://img.shields.io/pypi/status/memorable_password.svg)](https://pypi.python.org/pypi/memorable_password/)

Generate sentence of context, along with keywords/PIN/passwords to make sure you memorize it!!!

PIN memorization is based on [Major system](https://en.wikipedia.org/wiki/Mnemonic_major_system)

<a href="https://imgur.com/9SKe4IU"><img src="https://i.imgur.com/9SKe4IU.png" title="source: imgur.com" /></a>
<a href="https://imgur.com/arL46Hg"><img src="https://i.imgur.com/arL46Hg.png" title="source: imgur.com" /></a>
<a href="https://imgur.com/URNcUFX"><img src="https://i.imgur.com/URNcUFX.png" title="source: imgur.com" /></a>

## Memorable Password on Android

Memorable password has been tested to work with both PyDroid3 and QPython (Python 3.6).

- PyDroid3 - Kivy - See `/pydroid_run.py`
- QPython - Flask - See `/main.py`

## Related Project

https://github.com/patarapolw/randomsentence
